@@ -53,7 +53,7 @@
 #include "array_fun.h"
 #include "JsonDiskWriter.h"
 #ifdef ENABLE_XML_RPC
-#include "XmlRpcDiskWriter.h"
+#  include "XmlRpcDiskWriter.h"
 #endif // ENABLE_XML_RPC
 
 namespace aria2 {
@@ -188,7 +188,7 @@ bool HttpServer::receiveRequest()
     socketRecvBuffer_->drain(headerProcessor_->getLastBytesProcessed());
     bodyConsumed_ = 0;
     if (setupResponseRecv() < 0) {
-      A2_LOG_INFO("Request path is invaild. Ignore the request body.");
+      A2_LOG_INFO("Request path is invalid. Ignore the request body.");
     }
     const std::string& contentLengthHdr =
         lastRequestHeader_->find(HttpHeader::CONTENT_LENGTH);
